@@ -17,7 +17,7 @@
 ;; Homepage: https://github.com/magit/magit
 ;; Keywords: git tools vc
 
-;; Package-Version: 4.4.0
+;; Package-Version: 4.4.2
 ;; Package-Requires: (
 ;;     (emacs        "28.1")
 ;;     (compat       "30.1")
@@ -773,7 +773,7 @@ For X11 something like ~/.xinitrc should work.\n"
   (require 'magit-stash)
   (require 'magit-blame)
   (require 'magit-submodule)
-  (unless (load "magit-autoloads" t t)
+  (unless (require 'magit-autoloads nil t)
     (require 'magit-patch)
     (require 'magit-subtree)
     (require 'magit-ediff)
